@@ -345,23 +345,23 @@ legend("topleft", legend = c("mstop = c(mu = 30, sigma = 15)", "mstop = c(mu = 3
 
 
 ###################################################
-### code chunk number 33: cvrisk
+### code chunk number 33: cvrisk (eval = FALSE)
 ###################################################
-cores <- ifelse(grepl("linux|apple", R.Version()$platform), 2, 1)
-if (!file.exists("cvrisk/cvr_india.Rda")) {
-    set.seed(1907)
-    folds <- cv(model.weights(mod), type = "subsampling")
-    densegrid <- make.grid(max = c(mu = 5000, sigma = 500), min = 20,
-                           length.out = 10, dense_mu_grid = TRUE)
-    cvr <- cvrisk(mod, grid = densegrid, folds = folds, mc.cores = cores)
-    save("cvr", file = "cvrisk/cvr_india.Rda", compress = "xz")
-}
+## cores <- ifelse(grepl("linux|apple", R.Version()$platform), 2, 1)
+## if (!file.exists("cvrisk/cvr_india.Rda")) {
+##     set.seed(1907)
+##     folds <- cv(model.weights(mod), type = "subsampling")
+##     densegrid <- make.grid(max = c(mu = 5000, sigma = 500), min = 20,
+##                            length.out = 10, dense_mu_grid = TRUE)
+##     cvr <- cvrisk(mod, grid = densegrid, folds = folds, mc.cores = cores)
+##     save("cvr", file = "cvrisk/cvr_india.Rda", compress = "xz")
+## }
 
 
 ###################################################
-### code chunk number 34: load_cvrisk
+### code chunk number 34: load_cvrisk (eval = FALSE)
 ###################################################
-load("cvrisk/cvr_india.Rda")
+## load("cvrisk/cvr_india.Rda")
 
 
 ###################################################
@@ -371,48 +371,27 @@ load("cvrisk/cvr_india.Rda")
 
 
 ###################################################
-### code chunk number 36: crossvalidation
+### code chunk number 36: subset (eval = FALSE)
 ###################################################
-plot(cvr)
+## mstop(mod) <- mstop(cvr)
 
 
 ###################################################
-### code chunk number 37: mstop
-###################################################
-mstop(cvr)
-
-
-###################################################
-### code chunk number 38: check_initial_assignement
-###################################################
-## for the purpose of the tutorial we started already with the optimal number of
-## boosting steps. Check if this is really true:
-if (!isTRUE(all.equal(mstop(mod), mstop(cvr))))
-    warning("Check mstop(mod) throughout the manuscript.")
-
-
-###################################################
-### code chunk number 39: subset
-###################################################
-mstop(mod) <- mstop(cvr)
-
-
-###################################################
-### code chunk number 40: effects
+### code chunk number 37: effects
 ###################################################
 par(mfrow = c(2, 5))
 plot(mod)
 
 
 ###################################################
-### code chunk number 41: smooth_effects_code (eval = FALSE)
+### code chunk number 38: smooth_effects_code (eval = FALSE)
 ###################################################
 ## par(mfrow = c(2, 4), mar = c(5.1, 4.5, 4.1, 1.1))
 ## plot(mod, which = "bbs", type = "l")
 
 
 ###################################################
-### code chunk number 42: smooth_effects
+### code chunk number 39: smooth_effects
 ###################################################
 par(cex.axis = 1.3, cex.lab = 1.3, mar = c(4, 5, 2, 1))
 par(mfrow = c(2, 4), mar = c(5.1, 4.5, 4.1, 1.1))
@@ -420,19 +399,19 @@ plot(mod, which = "bbs", type = "l")
 
 
 ###################################################
-### code chunk number 43: smooth_effects_2
+### code chunk number 40: smooth_effects_2
 ###################################################
 plot(mod, which = "bbs", parameter = "mu")
 
 
 ###################################################
-### code chunk number 44: smooth_effects_3
+### code chunk number 41: smooth_effects_3
 ###################################################
 plot(mod, which = 1:4, parameter = 1)
 
 
 ###################################################
-### code chunk number 45: marginal_prediction_plot_code
+### code chunk number 42: marginal_prediction_plot_code
 ###################################################
 plot(predint(mod, pi = c(0.8, 0.9), which = "cbmi"),
      lty = 1:3, lwd = 3, xlab =  "BMI (child)",
@@ -440,14 +419,14 @@ plot(predint(mod, pi = c(0.8, 0.9), which = "cbmi"),
 
 
 ###################################################
-### code chunk number 46: greater_mumbai
+### code chunk number 43: greater_mumbai
 ###################################################
 points(stunting ~ cbmi, data = india, pch = 20,
        col = rgb(1, 0, 0, 0.5), subset = mcdist == "381")
 
 
 ###################################################
-### code chunk number 47: marginal_prediction_plot
+### code chunk number 44: marginal_prediction_plot
 ###################################################
 plot(predint(mod, pi = c(0.8, 0.9), which = "cbmi"),
      lty = 1:3, lwd = 3, xlab =  "BMI (child)",
@@ -457,7 +436,7 @@ points(stunting ~ cbmi, data = india, pch = 20,
 
 
 ###################################################
-### code chunk number 48: spatial_effects_code1 (eval = FALSE)
+### code chunk number 45: spatial_effects_code1 (eval = FALSE)
 ###################################################
 ## fitted_mu <- fitted(mod, parameter = "mu", which = "mcdist",
 ##                     type = "response")
@@ -466,7 +445,7 @@ points(stunting ~ cbmi, data = india, pch = 20,
 
 
 ###################################################
-### code chunk number 49: spatial_effects_code2 (eval = FALSE)
+### code chunk number 46: spatial_effects_code2 (eval = FALSE)
 ###################################################
 ## fitted_mu <- tapply(fitted_mu, india$mcdist, FUN = mean)
 ## fitted_sigma <- tapply(fitted_sigma, india$mcdist, FUN = mean)
@@ -480,7 +459,7 @@ points(stunting ~ cbmi, data = india, pch = 20,
 
 
 ###################################################
-### code chunk number 50: spatial_effects
+### code chunk number 47: spatial_effects
 ###################################################
 fitted_mu <- fitted(mod, parameter = "mu", which = "mcdist",
                     type = "response")
